@@ -5,13 +5,19 @@ trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
 
 test_that("PLNPCAfamily: main function, field access and methods", {
 
-  output <- "\n Initialization...\n\n Adjusting 5 PLN models for PCA analysis.\n Rank approximation = 1\n\t conservative convex separable approximation for gradient descent Rank approximation = 2\n\t conservative convex separable approximation for gradient descent Rank approximation = 3\n\t conservative convex separable approximation for gradient descent Rank approximation = 4\n\t conservative convex separable approximation for gradient descent Rank approximation = 5\n\t conservative convex separable approximation for gradient descent\n Post-treatments\n DONE!"
-
-  expect_output(models <- PLNPCA(Abundance ~ 1, data = trichoptera,
-                                 ranks = 1:5, control_main = list(trace = 2)),
-              output, fixed = TRUE)
+  ##  does not work because of future evaluating in random order the models
+  # output <- "\n Initialization...\n\n Adjusting 5 PLN models for PCA analysis.\n Rank approximation = 1\n\t conservative convex separable approximation for gradient descent Rank approximation = 2\n\t conservative convex separable approximation for gradient descent Rank approximation = 3\n\t conservative convex separable approximation for gradient descent Rank approximation = 4\n\t conservative convex separable approximation for gradient descent Rank approximation = 5\n\t conservative convex separable approximation for gradient descent\n Post-treatments\n DONE!"
+  #
+  models <- PLNPCA(Abundance ~ 1, data = trichoptera,
+                                  ranks = 1:5, control_main = list(trace = 0))
 
   expect_is(models, "PLNPCAfamily")
+  expect_is(plot(models), "ggplot")
+  expect_is(plot(models, reverse = TRUE), "ggplot")
+  expect_is(plot(models, map="individual"), "ggplot")
+  expect_is(plot(models, map="variable"), "ggplot")
+  expect_is(getBestModel(models), "PLNPCAfit")
+  expect_is(getModel(models, models$ranks[1]), "PLNPCAfit")
 
   X <- model.matrix(Abundance ~ 1, data = trichoptera)
   Y <- as.matrix(trichoptera$Abundance)
@@ -20,7 +26,7 @@ test_that("PLNPCAfamily: main function, field access and methods", {
   xlevels <- NULL
 
   ## extract the data matrices and weights
-  ctrl_init <- PLNmodels:::PLN_param(list(), nrow(Y), ncol(Y), ncol(X))
+  ctrl_init <- PLNmodels:::PLN_param(list(), nrow(Y), ncol(Y))
   ctrl_main <- PLNmodels:::PLNPCA_param(list())
 
   ## instantiate
@@ -32,8 +38,6 @@ test_that("PLNPCAfamily: main function, field access and methods", {
   ## post-treatment
   myPLN$postTreatment()
 
-  expect_equivalent(myPLN, models)
-
   ## S3 methods
   expect_true(PLNmodels:::isPLNPCAfamily(myPLN))
   expect_is(plot(myPLN), "ggplot")
@@ -44,7 +48,7 @@ test_that("PLNPCAfamily: main function, field access and methods", {
 
   ## test fail on Mac OS : fit is slightly different between OS X and Ubuntu
   ## probably due to the version of optimization libraries...
-#   ## Show method
+  ## Show method
 #   expect_output(models$show(),
 # "--------------------------------------------------------
 # COLLECTION OF 5 POISSON LOGNORMAL MODELS
@@ -52,9 +56,10 @@ test_that("PLNPCAfamily: main function, field access and methods", {
 #  Task: Principal Component Analysis
 # ========================================================
 #  - Ranks considered: from 1 to 5
-#  - Best model (greater BIC): rank = 4 - R2 = 0.98
-#  - Best model (greater ICL): rank = 4 - R2 = 0.98",
+#  - Best model (greater BIC): rank = 5
+#  - Best model (greater ICL): rank = 4",
 #   fixed = TRUE)
+
 })
 
 # test_that("PLNPCA is fast on low ranks", {
