@@ -50,17 +50,29 @@ test_that("PLNPCA fit: check classes, getters and field access", {
   expect_equal(vcov(myPLNfit, "main"), myPLNfit$fisher$mat)
   expect_equal(vcov(myPLNfit, "covariance"), myPLNfit$model_par$Sigma)
   expect_equal(vcov(myPLNfit, "covariance"), sigma(myPLNfit))
-  expect_equal(dim(standard_error(myPLNfit)), dim(coefficients(myPLNfit)))
+  # expect_equal(dim(standard_error(myPLNfit)), dim(coefficients(myPLNfit)))
 
   expect_true(inherits(plot(myPLNfit, map = "variable", plot = FALSE), "ggplot"))
   expect_true(inherits(plot(myPLNfit, map = "individual", plot = FALSE), "ggplot"))
   expect_true(inherits(plot(myPLNfit, map = "both", plot = FALSE), "grob"))
 
-  ## R6 methods
+  ## R6 methods: Plots
   expect_true(inherits(myPLNfit$plot_correlation_circle(plot = FALSE), "ggplot"))
   expect_true(inherits(myPLNfit$plot_individual_map(plot = FALSE), "ggplot"))
   expect_true(inherits(myPLNfit$plot_PCA(plot = FALSE), "grob"))
 
+  ## R6 methods: VEstep
+  ve_results <- myPLNfit$VEstep(covariates = X, offsets = O, responses = Y)
+  expect_equal(dim(ve_results$M), c(n, myPLNfit$rank))
+  expect_equal(dim(ve_results$S2), c(n, myPLNfit$rank))
+  expect_length(ve_results$log.lik, n)
+  expect_equal(ve_results$M, unname(myPLNfit$var_par$M), tolerance = 1e-2)
+  ## R6 methods: project()
+  scores <- myPLNfit$project(newdata = trichoptera)
+  expect_equal(dim(scores), dim(myPLNfit$scores))
+  expect_equal(dimnames(scores), dimnames(myPLNfit$scores))
+  expect_equal(scores, myPLNfit$scores, tolerance = 1e-2)
+
   ## Class
   expect_true(inherits(myPLNfit, "PCA"))
 })
